@@ -1,4 +1,4 @@
-from typing import List, Dict, Any, Optional, Callable
+from typing import Sequence, List, Dict, Any, Optional, Callable
 import os
 import tempfile
 
@@ -29,13 +29,19 @@ class BertPreprocessingLayer(tf.keras.layers.Layer):
 
     def __init__(
         self,
-        vocab: List[str] = None,
+        vocab: Sequence[str],
         cls_token: str = "[CLS]",
         sep_token: str = "[SEP]",
         **kwargs
     ) -> None:
+        vocab: List = list(vocab)
         self.cls_token = cls_token
         self.sep_token = sep_token
+        if cls_token not in vocab:
+            vocab.append(cls_token)
+        if sep_token not in vocab:
+            vocab.append(sep_token)
+        self.vocab = vocab
         self.tokenizer = tftext.BertTokenizer(
             tf.lookup.StaticVocabularyTable(
                 tf.lookup.KeyValueTensorInitializer(
@@ -52,21 +58,20 @@ class BertPreprocessingLayer(tf.keras.layers.Layer):
                 self.cls_id = i
             if token == sep_token:
                 self.sep_id = i
-        self.vocab = vocab
         super().__init__(**kwargs)
 
     def call(self, inputs: tf.Tensor) -> tf.Tensor:
-        tokens = self.tokenizer.tokenize(inputs)
-        flatten_tokens = tokens.merge_dims(-2, -1)
-        cls_tokens = tf.reshape(
-            tf.tile(tf.constant([self.cls_id], dtype=tf.int64), [tokens.nrows()]),
-            [tokens.nrows(), 1]
+        token_ids = self.tokenizer.tokenize(inputs)
+        flatten_ids = token_ids.merge_dims(-2, -1)
+        cls_ids = tf.reshape(
+            tf.tile(tf.constant([self.cls_id], dtype=tf.int64), [token_ids.nrows()]),
+            [token_ids.nrows(), 1]
         )
-        sep_tokens = tf.reshape(
-            tf.tile(tf.constant([self.sep_id], dtype=tf.int64), [tokens.nrows()]),
-            [tokens.nrows(), 1]
+        sep_ids = tf.reshape(
+            tf.tile(tf.constant([self.sep_id], dtype=tf.int64), [token_ids.nrows()]),
+            [token_ids.nrows(), 1]
         )
-        ids = tf.concat([cls_tokens, flatten_tokens, sep_tokens], axis=1)
+        ids = tf.concat([cls_ids, flatten_ids, sep_ids], axis=1)
         return ids.to_tensor(0)
 
     def get_config(self) -> Dict[str, Any]:
