@@ -23,6 +23,14 @@ class BaseNLPModel:
         self._name = name
         self._built = False
 
+    @property
+    def max_sequence_length(self) -> Optional[int]:
+        return self._max_sequence_length
+
+    @property
+    def sequence_length(self) -> Optional[int]:
+        return self._sequence_length
+
     @staticmethod
     def build_vocab(
         texts: Sequence[str],
@@ -51,42 +59,10 @@ class BaseNLPModel:
     def get_inputs(self) -> tf.Tensor:
         raise NotImplementedError()
 
-    @property
-    def sequence_length(self):
-        return self._sequence_length
-
-    @property
-    def max_sequence_length(self):
-        return self._max_sequence_length
-
-    @property
-    def input_names(self) -> List[str]:
-        return []
-
-    @property
-    def input_types(self) -> List[str]:
-        return []
-
-    @property
-    def input_shapes(self) -> List[List[int]]:
-        return []
-
     def get_outputs(self) -> tf.Tensor:
         raise NotImplementedError()
 
-    @property
-    def output_names(self) -> List[str]:
-        return []
-
-    @property
-    def output_types(self) -> List[str]:
-        return []
-
-    @property
-    def output_shapes(self) -> List[List[int]]:
-        return []
-
-    def get_loss(self):
+    def get_loss(self) -> tf.keras.losses.Loss:
         raise NotImplementedError()
 
     def get_metrics(self):
