@@ -1,4 +1,4 @@
-from typing import Sequence, List, Dict, Any, Optional, Union
+from typing import Sequence, Optional
 
 import tensorflow as tf
 from tensorflow.keras.layers import Dropout
@@ -27,7 +27,7 @@ class BertClassifier(DeepClassifier):
         output_dropout: float = 0.5,
         text2vec: Optional[Bert2vec] = None,
         **kwargs
-    ):
+    ) -> None:
         super().__init__(classes,
                          is_multilabel=is_multilabel,
                          segmenter=segmenter,
