@@ -8,6 +8,7 @@ import tensorflow as tf
 from sknlp.vocab import Vocab
 from sknlp.data import ClassificationDataset
 from sknlp.metrics import PrecisionWithLogits, RecallWithLogits
+from sknlp.losses import SoftFScoreLoss
 from sknlp.callbacks import FScore
 
 from ..supervised_model import SupervisedNLPModel
@@ -31,6 +32,7 @@ class DeepClassifier(SupervisedNLPModel):
         segmenter: str = "jieba",
         embedding_size: int = 100,
         text2vec: Optional[Text2vec] = None,
+        loss: str = None,
         **kwargs
     ):
         super().__init__(classes,
@@ -42,8 +44,11 @@ class DeepClassifier(SupervisedNLPModel):
                          task="classification",
                          **kwargs)
         self._is_multilabel = is_multilabel
+        self._loss = loss
 
     def get_loss(self):
+        if self._loss is not None:
+            return SoftFScoreLoss(is_multilabel=self._is_multilabel, from_logits=True)
         if self._is_multilabel:
             return tf.keras.losses.BinaryCrossentropy(from_logits=True)
         else:
