@@ -4,11 +4,13 @@ import os
 import logging
 
 import tensorflow as tf
+import tensorflow_addons as tfa
 import pandas as pd
 
 from ..data import NLPDataset
 from ..data.text_segmenter import get_segmenter
 from ..vocab import Vocab
+from ..callbacks import WeightDecayScheduler
 from .text2vec import Word2vec, Text2vec
 from .base_model import BaseNLPModel
 
@@ -76,18 +78,6 @@ class SupervisedNLPModel(BaseNLPModel):
     def get_inputs(self) -> tf.Tensor:
         return self._text2vec.get_inputs()
 
-    @property
-    def input_names(self) -> List[str]:
-        return self._text2vec.input_names if self._text2vec else []
-
-    @property
-    def input_types(self) -> List[str]:
-        return self._text2vec.input_types if self._text2vec else []
-
-    @property
-    def input_shapes(self) -> List[List[int]]:
-        return self._text2vec.input_shapes if self._text2vec else []
-
     def get_outputs(self) -> tf.Tensor:
         inputs = self._text2vec.get_outputs()
         return self.build_output_layer(self.build_encode_layer(inputs))
@@ -149,6 +139,7 @@ class SupervisedNLPModel(BaseNLPModel):
         n_epochs: int = 30,
         optimizer: str = "adam",
         lr: float = 1e-3,
+        weight_decay: float = 1e-4,
         lr_update_factor: float = 0.5,
         lr_update_epochs: int = 10,
         clip: float = 5.0,
@@ -162,7 +153,7 @@ class SupervisedNLPModel(BaseNLPModel):
         verbose: int = 2
     ) -> None:
         assert not (self._text2vec is None and X is None), \
-            "When token2vec is not given, X must be provided"
+            "When text2vec is not given, X must be provided"
 
         self.train_dataset = self.prepare_tf_dataset(X, y, dataset, batch_size)
         if ((valid_X is None or valid_y is None) and valid_dataset is None):
@@ -173,7 +164,7 @@ class SupervisedNLPModel(BaseNLPModel):
             )
         if not self._built:
             self.build()
-        optimizer = tf.keras.optimizers.Adam(learning_rate=lr, clipnorm=clip)
+        optimizer = tfa.optimizers.AdamW(weight_decay, learning_rate=lr, clipnorm=clip)
         if optimizer != "adam":
             pass
         loss = self.get_loss()
@@ -181,14 +172,17 @@ class SupervisedNLPModel(BaseNLPModel):
         callbacks = self.get_callbacks()
         self._model.compile(optimizer=optimizer, loss=loss, metrics=metrics)
 
-        def scheduler(epoch):
-            new_lr = lr * lr_update_factor ** (epoch // lr_update_epochs)
-            if epoch != 0 and epoch % lr_update_epochs == 0:
-                logger.info("change learning rate to %.4g" % new_lr)
-            return new_lr
+        def lr_scheduler(epoch, lr):
+            return lr * lr_update_factor ** ((epoch + 1) % lr_update_epochs == 0)
 
-        lr_decay = tf.keras.callbacks.LearningRateScheduler(scheduler)
-        callbacks = [*callbacks, lr_decay]
+        def wd_scheduler(epoch, wd):
+            return wd * lr_update_factor ** ((epoch + 1) % lr_update_epochs == 0)
+
+        lr_decay = tf.keras.callbacks.LearningRateScheduler(
+            lr_scheduler, verbose=verbose
+        )
+        weight_decay = WeightDecayScheduler(wd_scheduler, verbose=verbose)
+        callbacks = [*callbacks, lr_decay, weight_decay]
         if enable_early_stopping:
             callbacks.append(tf.keras.callbacks.EarlyStopping(
                 monitor=self.get_monitor(),
