@@ -1,4 +1,4 @@
-from typing import Optional, List, Dict, Any
+from typing import Optional, Dict, Any
 import os
 from collections import Counter
 
@@ -42,10 +42,9 @@ class Bert2vec(Text2vec):
             **kwargs
         )
         self._hidden_size = hidden_size
-        self._only_output_cls = False
         bert_preprocessing_layer = BertPreprocessingLayer(self.vocab.sorted_tokens)
         bert_layer = BertLayer(
-            len(self.vocab),
+            len(bert_preprocessing_layer.get_config()["vocab"]),
             hidden_size=hidden_size,
             num_layers=num_layers,
             num_attention_heads=num_attention_heads,
@@ -119,7 +118,6 @@ class Bert2vec(Text2vec):
         only_output_cls: bool = False
     ) -> None:
         if only_output_cls:
-            self._only_output_cls = True
             self._model = tf.keras.Model(
                 inputs=self._model.inputs,
                 outputs=self._model.outputs[1:],
@@ -168,7 +166,6 @@ class Albert2vec(Text2vec):
             **kwargs
         )
         self._embedding_size = embedding_size
-        self._only_output_cls = False
         bert_preprocessing_layer = BertPreprocessingLayer(self.vocab.sorted_tokens)
         bert_layer = AlbertLayer(
             len(self.vocab),
@@ -245,7 +242,6 @@ class Albert2vec(Text2vec):
         only_output_cls: bool = False
     ) -> None:
         if only_output_cls:
-            self._only_output_cls = True
             self._model = tf.keras.Model(
                 inputs=self._model.inputs,
                 outputs=self._model.outputs[1:],
