@@ -1,4 +1,4 @@
-from typing import Optional, Dict, Any, List
+from typing import Optional, Dict, Any
 
 import tensorflow as tf
 from tensorflow.keras.layers import Embedding
@@ -73,30 +73,6 @@ class Word2vec(Text2vec):
     def embedding_size(self) -> int:
         return self._embedding_size
 
-    @property
-    def input_names(self) -> List[str]:
-        return ["embeddings_input"]
-
-    @property
-    def input_types(self) -> List[str]:
-        return ["float"]
-
-    @property
-    def input_shapes(self) -> List[List[int]]:
-        return [[-1, -1]]
-
-    @property
-    def output_names(self) -> List[str]:
-        return ["embeddings"]
-
-    @property
-    def output_types(self) -> List[str]:
-        return ["float"]
-
-    @property
-    def output_shapes(self) -> List[List[int]]:
-        return [[-1, self.embedding_size]]
-
     def get_config(self) -> Dict[str, Any]:
         return {
             **super().get_config(),
